summaryrefslogtreecommitdiff
path: root/include/ruby/internal/core/rfile.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/ruby/internal/core/rfile.h')
-rw-r--r--include/ruby/internal/core/rfile.h9
1 files changed, 4 insertions, 5 deletions
diff --git a/include/ruby/internal/core/rfile.h b/include/ruby/internal/core/rfile.h
index 8cf2c4db5b..f8dddde9e5 100644
--- a/include/ruby/internal/core/rfile.h
+++ b/include/ruby/internal/core/rfile.h
@@ -23,10 +23,9 @@
#include "ruby/internal/core/rbasic.h"
#include "ruby/internal/cast.h"
-/* rb_io is in ruby/io.h and internal/io.h. The header file has historically
- * not been included into ruby/ruby.h. We follow that tradition.
- */
-struct rb_io;
+/* rb_io_t is in ruby/io.h. The header file has historically not been included
+ * into ruby/ruby.h. We follow that tradition. */
+struct rb_io_t;
/**
* Ruby's File and IO. Ruby's IO are not just file descriptors. They have
@@ -39,7 +38,7 @@ struct RFile {
struct RBasic basic;
/** IO's specific fields. */
- struct rb_io *fptr;
+ struct rb_io_t *fptr;
};
/**